==> neper-1.8.0.tgz: neper-1.8.0/src/ut/ut_board/ut_board0.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2004-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */
 
#ifndef UT_BOARD0_H
#define UT_BOARD0_H

extern void ut_board_1d_scale (double *, int, double);
extern void ut_board_1d_int_scale (int *, int, int);
extern void ut_board_1d_add (double *, double *, int, double *);
extern double ut_board_1d_norm (double *, int);
extern double ut_board_1d_norm_int (int *, int);
extern void ut_board_1d_zero (double *, int);
extern void ut_board_1d_int_zero (int *, int);
extern void ut_board_2d_zero (double **, int, int);
extern void ut_board_2d_int_zero (int **, int, int);
extern void ut_board_1d_zero_be (double *, int, int);
extern void ut_board_1d_float_zero_be (float *, int, int);
extern void ut_board_1d_int_zero_be (int *, int, int);
extern void ut_board_2d_zero_be (double **, int, int, int, int);
extern void ut_board_2d_float_zero_be (float **, int, int, int, int);
extern void ut_board_2d_int_zero_be (int **, int, int, int, int);
extern int ut_board_1d_fscanf (FILE *, double *, int);
extern int ut_board_1d_int_fscanf (FILE *, int *, int);
extern int ut_board_2d_fscanf (FILE *, double **, int, int);
extern int ut_board_1d_fprintf (FILE *, double *, int, char *);
extern int ut_board_1d_int_fprintf (FILE *, int *, int, char *);
extern int ut_board_2d_int_fprintf (FILE *, int **, int, int, char *);
extern int ut_board_2d_fprintf (FILE *, double **, int, int, char *);
extern int ut_board_2d_int_fscanf (FILE *, int **, int, int);
extern void ut_board_2d_scale (double **, int, int, double);

extern double ut_board_1d_min (double *, int);
extern int ut_board_1d_min_index (double *, int);
extern int ut_board_1d_min2_index (double *, int);
extern double ut_board_1d_max (double *, int);
extern double ut_board_1d_mean (double *, int);
extern double ut_board_1d_wmean (double *, double *, int);
extern double ut_board_1d_stddev (double *, double, int);
extern double ut_board_1d_absmax (double *, int);
extern int ut_board_1d_max_index (double *, int);
extern int ut_board_1d_absmax_index (double *, int);
extern int ut_board_1d_int_min (int *, int);
extern int ut_board_1d_int_max (int *, int);
extern int ut_board_1d_int_max_index (int *, int);
extern double ut_board_1d_sum (double *, int);
extern int ut_board_1d_int_sum (int *, int);
extern double ut_board_1d_abssum (double *, int);
extern int ut_board_1d_int_abssum (int *, int);
extern void ut_board_1d_abs (double *, int);
extern void ut_board_1d_int_abs (int *, int);

extern void ut_board_1d_memcpy (double *, int, double *);
extern void ut_board_1d_int_memcpy (int *, int, int *);
extern void ut_board_2d_memcpy (double **, int, int, double **);
extern void ut_board_2d_int_memcpy (int **, int, int, int **);

extern void ut_board_1d_exchange (double *, int, int);
extern void ut_board_1d_int_exchange (int *, int, int);
extern void ut_board_1d_sort (double *, int);
extern void ut_board_1d_sort_des (double *, int);
extern void ut_board_1d_sort_index (double *, int, int *);
extern void ut_board_1d_int_sort (int *, int);
extern void ut_board_1d_int_sort_index (int *, int, int *);
extern void ut_board_1d_int_dsort (int *, int);
extern void ut_board_1d_int_dsort_index (int *, int, int *);
extern void ut_board_1d_abssort (double *, int);
extern void ut_board_1d_abssort_index (double *, int, int *);
extern void ut_board_1d_int_abssort_index (int *, int, int *);
extern int ut_board_1d_int_find (int *, int, int);

extern void ut_board_1d_view (double *, int);
extern void ut_board_2d_view (double **, int, int);
extern void ut_board_1d_int_view (int *, int);
extern void ut_board_2d_int_view (int **, int, int);

extern void ut_board_2d_int_exchangelines (int **, int, int, int, int);

extern void ut_board_1d_int_bubbleelt (int *, int, int);

extern void ut_board_1d_int_rotate (int *, int, int);

extern void ut_board_1d_int_reverseelts (int *, int);
extern int ut_board_1d_max_int_index (int *, int);
#endif /* UT_BOARD0_H */
extern void ut_board_1d_permutation (double *, int, int *);
extern void ut_board_1d_permutation_int (int *, int, int *);
extern void ut_board_2d_permutation_int (int **, int, int, int *);

extern void ut_board_distribparam (double *, int, double, double *, int *);
extern void ut_board_distrib (double *, int, double, double, int, double *);

extern void ut_board_1d_set (double *, int, double);
extern void ut_board_1d_int_set (int *, int, int);
extern void ut_board_2d_set (double **, int, int, double);
extern void ut_board_2d_int_set (int **, int, int, int);
extern void ut_board_3d_set (double ***, int, int, int, double);
extern void ut_board_3d_int_set (int ***, int, int, int, int);
extern int ut_board_1d_rotpos (int, int, int, int);
extern int ut_board_1d_int_eltpos (int *, int, int);
extern int ut_board_2d_int_eltpos (int **, int, int, int, int *, int *);
extern int ut_board_1d_string_eltpos (char**, int, char*);

extern double ut_board_1d_valuepos (double*, int, double);
extern void ut_board_1d_inter (int*, int, int*, int, int**, int*);
extern void ut_board_1d_int_compress (int *, int*);
extern void ut_board_1d_int_sortncompress (int*, int, int*);
extern void ut_board_1d_sub (double*, double*, int, double*);

extern void ut_board_1d_sample (double*, int, double, double**, int*);
extern void ut_board_2d_sample (double**, int, int, double, double***, int*);

extern int ut_board_1d_fscanf_sample (FILE*, int, double, double**, int*);
extern int ut_board_2d_fscanf_sample (FILE*, int, int, double, double***, int*);

extern int ut_board_1d_int_nbofthisval (int *, int, int);
extern void ut_board_1d_commonelts (int*, int, int*, int, int**, int*);
extern int * ut_board_1d_int_cat (int *, int, int *, int);
extern int ut_board_1d_int_deletencompress (int *, int, int, int);
extern void ut_board_1d_int_memcpy_be (int *, int*, int, int);

==> neper-1.8.1.tgz: neper-1.8.1/src/ut/ut_board/ut_board0.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2004-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */
 
#ifndef UT_BOARD0_H
#define UT_BOARD0_H

extern void ut_board_1d_scale (double *, int, double);
extern void ut_board_1d_int_scale (int *, int, int);
extern void ut_board_1d_add (double *, double *, int, double *);
extern void ut_board_1d_addval (double *, int, double, double *);
extern void ut_board_1d_int_addval (int *, int, int, int *);
extern double ut_board_1d_norm (double *, int);
extern double ut_board_1d_norm_int (int *, int);
extern void ut_board_1d_zero (double *, int);
extern void ut_board_1d_int_zero (int *, int);
extern void ut_board_2d_zero (double **, int, int);
extern void ut_board_2d_int_zero (int **, int, int);
extern void ut_board_1d_zero_be (double *, int, int);
extern void ut_board_1d_float_zero_be (float *, int, int);
extern void ut_board_1d_int_zero_be (int *, int, int);
extern void ut_board_2d_zero_be (double **, int, int, int, int);
extern void ut_board_2d_float_zero_be (float **, int, int, int, int);
extern void ut_board_2d_int_zero_be (int **, int, int, int, int);
extern int ut_board_1d_fscanf (FILE *, double *, int);
extern int ut_board_1d_int_fscanf (FILE *, int *, int);
extern int ut_board_2d_fscanf (FILE *, double **, int, int);
extern int ut_board_1d_fprintf (FILE *, double *, int, char *);
extern int ut_board_1d_int_fprintf (FILE *, int *, int, char *);
extern int ut_board_2d_int_fprintf (FILE *, int **, int, int, char *);
extern int ut_board_2d_fprintf (FILE *, double **, int, int, char *);
extern int ut_board_2d_int_fscanf (FILE *, int **, int, int);
extern void ut_board_2d_scale (double **, int, int, double);

extern double ut_board_1d_min (double *, int);
extern int ut_board_1d_min_index (double *, int);
extern int ut_board_1d_min2_index (double *, int);
extern double ut_board_1d_max (double *, int);
extern double ut_board_1d_mean (double *, int);
extern double ut_board_1d_wmean (double *, double *, int);
extern double ut_board_1d_stddev (double *, double, int);
extern double ut_board_1d_absmax (double *, int);
extern int ut_board_1d_max_index (double *, int);
extern int ut_board_1d_absmax_index (double *, int);
extern int ut_board_1d_int_min (int *, int);
extern int ut_board_1d_int_max (int *, int);
extern int ut_board_1d_int_max_index (int *, int);
extern double ut_board_1d_sum (double *, int);
extern int ut_board_1d_int_sum (int *, int);
extern double ut_board_1d_abssum (double *, int);
extern int ut_board_1d_int_abssum (int *, int);
extern void ut_board_1d_abs (double *, int);
extern void ut_board_1d_int_abs (int *, int);

extern void ut_board_1d_memcpy (double *, int, double *);
extern void ut_board_1d_int_memcpy (int *, int, int *);
extern void ut_board_2d_memcpy (double **, int, int, double **);
extern void ut_board_2d_int_memcpy (int **, int, int, int **);

extern void ut_board_1d_exchange (double *, int, int);
extern void ut_board_1d_int_exchange (int *, int, int);
extern void ut_board_1d_sort (double *, int);
extern void ut_board_1d_sort_des (double *, int);
extern void ut_board_1d_sort_index (double *, int, int *);
extern void ut_board_1d_int_sort (int *, int);
extern void ut_board_1d_int_sort_index (int *, int, int *);
extern void ut_board_1d_int_dsort (int *, int);
extern void ut_board_1d_int_dsort_index (int *, int, int *);
extern void ut_board_1d_abssort (double *, int);
extern void ut_board_1d_abssort_index (double *, int, int *);
extern void ut_board_1d_int_abssort_index (int *, int, int *);
extern int ut_board_1d_int_find (int *, int, int);

extern void ut_board_1d_view (double *, int);
extern void ut_board_2d_view (double **, int, int);
extern void ut_board_1d_int_view (int *, int);
extern void ut_board_2d_int_view (int **, int, int);

extern void ut_board_2d_exchangelines (double **, int, int, int);
extern void ut_board_2d_int_exchangelines (int **, int, int, int);

extern void ut_board_1d_int_bubbleelt (int *, int, int);

extern void ut_board_1d_int_rotate (int *, int, int);

extern void ut_board_1d_int_reverseelts (int *, int);
extern int ut_board_1d_max_int_index (int *, int);
#endif /* UT_BOARD0_H */
extern void ut_board_1d_permutation (double *, int, int *);
extern void ut_board_1d_permutation_int (int *, int, int *);
extern void ut_board_2d_permutation_int (int **, int, int, int *);

extern void ut_board_distribparam (double *, int, double, double *, int *);
extern void ut_board_distrib (double *, int, double, double, int, double *);

extern void ut_board_1d_set (double *, int, double);
extern void ut_board_1d_int_set (int *, int, int);
extern void ut_board_2d_set (double **, int, int, double);
extern void ut_board_2d_int_set (int **, int, int, int);
extern void ut_board_3d_set (double ***, int, int, int, double);
extern void ut_board_3d_int_set (int ***, int, int, int, int);
extern int ut_board_1d_rotpos (int, int, int, int);
extern int ut_board_1d_int_eltpos (int *, int, int);
extern int ut_board_2d_int_eltpos (int **, int, int, int, int *, int *);
extern int ut_board_1d_string_eltpos (char**, int, char*);

extern double ut_board_1d_valuepos (double*, int, double);
extern void ut_board_1d_inter (int*, int, int*, int, int**, int*);
extern void ut_board_1d_int_compress (int *, int*);
extern void ut_board_1d_int_sortncompress (int*, int, int*);
extern void ut_board_1d_sub (double*, double*, int, double*);

extern void ut_board_1d_sample (double*, int, double, double**, int*);
extern void ut_board_2d_sample (double**, int, int, double, double***, int*);

extern int ut_board_1d_fscanf_sample (FILE*, int, double, double**, int*);
extern int ut_board_2d_fscanf_sample (FILE*, int, int, double, double***, int*);

extern int ut_board_1d_int_nbofthisval (int *, int, int);
extern void ut_board_1d_commonelts (int*, int, int*, int, int**, int*);
extern int * ut_board_1d_int_cat (int *, int, int *, int);
extern int ut_board_1d_int_deletencompress (int *, int, int, int);
extern void ut_board_1d_int_memcpy_be (int *, int*, int, int);

extern void ut_board_1d_int_union (int*, int, int*, int, int*, int);
extern void ut_board_1d_int_minus (int*, int, int*, int, int*, int);

extern void ut_board_1d_int_inter (int*, int, int*, int, int*, int*);
